@@ -20,24 +20,24 @@ def normalize_with_expected_power(pv, power_expected, poa_global,
 
     Parameters
     ----------
-    pv : pd.Series
+    pv : pandas.Series
         Right-labeled time series PV energy or power. If energy, should *not*
         be cumulative, but only for preceding time step. Type (energy or power)
         must be specified in the ``pv_input`` parameter.
-    power_expected : pd.Series
+    power_expected : pandas.Series
         Right-labeled time series of expected PV power. (Note: Expected energy
         is not supported.)
-    poa_global : pd.Series
+    poa_global : pandas.Series
         Right-labeled time series of plane-of-array irradiance associated with
         ``expected_power``
-    pv_input : {'power' or 'energy'}
+    pv_input : str, {'power' or 'energy'}
         Specifies the type of input used for ``pv`` parameter. Default: 'power'
 
     Returns
     -------
-    energy_normalized : pd.Series
+    energy_normalized : pandas.Series
         Energy normalized based on ``power_expected``
-    insolation : pd.Series
+    insolation : pandas.Series
         Insolation associated with each normalized point
 
     '''
@@ -82,11 +82,11 @@ def pvwatts_dc_power(poa_global, power_dc_rated, temperature_cell=None,
 
     Parameters
     ----------
-    poa_global : pd.Series
-        Total effective plane of array irradiance.
+    poa_global : pandas.Series
+        Total effective plane of array irradiance [W/m**2].
     power_dc_rated : float
-        Rated DC power of array in watts
-    temperature_cell : pd.Series, optional
+        Rated DC power of array [W]
+    temperature_cell : pandas.Series, optional
         Measured or derived cell temperature [degrees Celsius].
         Time series assumed to be same frequency as ``poa_global``.
         If omitted, the temperature term will be ignored.
@@ -105,8 +105,8 @@ def pvwatts_dc_power(poa_global, power_dc_rated, temperature_cell=None,
 
     Returns
     -------
-    power_dc : pd.Series
-        DC power in watts determined by PVWatts v5 equation.
+    power_dc : pandas.Series
+        DC power determined by PVWatts v5 equation [W].
     '''
 
     power_dc = power_dc_rated * poa_global / poa_global_ref
@@ -129,20 +129,20 @@ def normalize_with_pvwatts(energy, pvwatts_kws):
 
     Parameters
     ----------
-    energy : pd.Series
-        Energy time series to be normalized in watt hours.
+    energy : pandas.Series
+        Energy time series to be normalized [Wh].
         Must be a right-labeled regular time series.
     pvwatts_kws : dict
         Dictionary of parameters used in the pvwatts_dc_power function.  See
         Other Parameters.
 
     Other Parameters
-    ------------------
-    poa_global : pd.Series
-        Total effective plane of array irradiance.
+    ----------------
+    poa_global : pandas.Series
+        Total effective plane of array irradiance [W/m**2].
     power_dc_rated : float
-        Rated DC power of array in watts
-    temperature_cell : pd.Series, optional
+        Rated DC power of array [W]
+    temperature_cell : pandas.Series, optional
         Measured or derived cell temperature [degrees Celsius].
         Time series assumed to be same frequency as `poa_global`.
         If omitted, the temperature term will be ignored.
@@ -161,10 +161,10 @@ def normalize_with_pvwatts(energy, pvwatts_kws):
 
     Returns
     -------
-    energy_normalized : pd.Series
-        Energy divided by PVWatts DC energy.
-    insolation : pd.Series
-        Insolation associated with each normalized point
+    energy_normalized : pandas.Series
+        Energy divided by PVWatts DC energy [unitless].
+    insolation : pandas.Series
+        Insolation associated with each normalized point [Wh/m**2]
     '''
 
     power_dc = pvwatts_dc_power(**pvwatts_kws)
@@ -185,14 +185,19 @@ def sapm_dc_power(pvlib_pvsystem, met_data):
     speed. Effective irradiance and cell temperature are calculated with SAPM,
     and DC power with PVWatts.
 
+    .. warning::
+        The ``pvlib_pvsystem`` argument must be a ``pvlib.pvsystem.LocalizedPVSystem``
+        object, which is no longer available as of pvlib 0.9.0.  To use this function
+        you'll need to use an older version of pvlib.
+
     Parameters
     ----------
-    pvlib_pvsystem : pvlib-python LocalizedPVSystem object
+    pvlib_pvsystem : pvlib.pvsystem.LocalizedPVSystem
         Object contains orientation, geographic coordinates, equipment
         constants (including DC rated power in watts).  The object must also
         specify either the ``temperature_model_parameters`` attribute or both
         ``racking_model`` and ``module_type`` attributes to infer the temperature model parameters.
-    met_data : pd.DataFrame
+    met_data : pandas.DataFrame
         Measured irradiance components, ambient temperature, and wind speed.
         Expected met_data DataFrame column names:
         ['DNI', 'GHI', 'DHI', 'Temperature', 'Wind Speed']
@@ -204,10 +209,10 @@ def sapm_dc_power(pvlib_pvsystem, met_data):
 
     Returns
     -------
-    power_dc : pd.Series
+    power_dc : pandas.Series
         DC power in watts derived using Sandia Array Performance Model and
         PVWatts.
-    effective_poa : pd.Series
+    effective_poa : pandas.Series
         Effective irradiance calculated with SAPM
     '''
 
@@ -257,9 +262,14 @@ def normalize_with_sapm(energy, sapm_kws):
 
     Energy timeseries and met_data timeseries can be different granularities.
 
+    .. warning::
+        The ``pvlib_pvsystem`` argument must be a ``pvlib.pvsystem.LocalizedPVSystem``
+        object, which is no longer available as of pvlib 0.9.0.  To use this function
+        you'll need to use an older version of pvlib.
+
     Parameters
     ----------
-    energy : pd.Series
+    energy : pandas.Series
         Energy time series to be normalized  in watt hours.
         Must be a right-labeled regular time series.
     sapm_kws : dict
@@ -268,12 +278,12 @@ def normalize_with_sapm(energy, sapm_kws):
 
     Other Parameters
     ---------------
-    pvlib_pvsystem : pvlib-python LocalizedPVSystem object
+    pvlib_pvsystem : pvlib.pvsystem.LocalizedPVSystem object
         Object contains orientation, geographic coordinates, equipment
         constants (including DC rated power in watts).  The object must also
         specify either the ``temperature_model_parameters`` attribute or both
         ``racking_model`` and ``module_type`` to infer the model parameters.
-    met_data : pd.DataFrame
+    met_data : pandas.DataFrame
         Measured met_data, ambient temperature, and wind speed.  Expected
         column names are ['DNI', 'GHI', 'DHI', 'Temperature', 'Wind Speed']
 
@@ -284,9 +294,9 @@ def normalize_with_sapm(energy, sapm_kws):
 
     Returns
     -------
-    energy_normalized : pd.Series
+    energy_normalized : pandas.Series
         Energy divided by Sandia Model DC energy.
-    insolation : pd.Series
+    insolation : pandas.Series
         Insolation associated with each normalized point
     '''
 
@@ -305,12 +315,12 @@ def _delta_index(series):
 
     Parameters
     ----------
-    series : pd.Series
+    series : pandas.Series
         A pandas timeseries
 
     Returns
     -------
-    deltas : pd.Series
+    deltas : pandas.Series
         A timeseries representing the timestep sizes of ``series``
     mean : float
         The average timestep
@@ -320,7 +330,7 @@ def _delta_index(series):
         # If there is no frequency information, explicitly calculate interval
         # sizes. Length of each interval calculated by using 'int64' to convert
         # to nanoseconds.
-        hours = pd.Series(series.index.astype('int64') / (10.0**9 * 3600.0))
+        hours = pd.Series(series.index.view('int64') / (10.0**9 * 3600.0))
         hours.index = series.index
         deltas = hours.diff()
     else:
@@ -328,9 +338,9 @@ def _delta_index(series):
         # a meaningful interval for the first element of the timeseries
         # Length of each interval calculated by using 'int64' to convert to
         # nanoseconds.
-        deltas = (series.index - series.index.shift(-1)).astype('int64') / \
+        deltas = (series.index - series.index.shift(-1)).view('int64') / \
                  (10.0**9 * 3600.0)
-    return deltas, np.mean(deltas.dropna())
+    return deltas, np.mean(deltas[~np.isnan(deltas)])
 
 
 delta_index = deprecated('2.0.0', removal='3.0.0')(_delta_index)
@@ -344,9 +354,9 @@ def irradiance_rescale(irrad, irrad_sim, max_iterations=100,
 
     Parameters
     ----------
-    irrad : pd.Series
+    irrad : pandas.Series
         measured irradiance time series
-    irrad_sim : pd.Series
+    irrad_sim : pandas.Series
         modeled/simulated irradiance time series
     max_iterations : int, default 100
         The maximum number of times to attempt rescale optimization.
@@ -365,7 +375,7 @@ def irradiance_rescale(irrad, irrad_sim, max_iterations=100,
 
     Returns
     -------
-    pd.Series
+    pandas.Series
         Rescaled modeled irradiance time series
     '''
 
@@ -436,7 +446,7 @@ def _check_series_frequency(series, series_description):
 
     Parameters
     ----------
-    series : pd.Series
+    series : pandas.Series
         The timeseries to infer the frequency of.
     series_description : str
         The description to use when raising an error.
@@ -467,7 +477,7 @@ def _t_step_nanoseconds(time_series):
     return a series of right labeled differences in the index of time_series
     in nanoseconds
     '''
-    t_steps = np.diff(time_series.index.astype('int64')).astype('float')
+    t_steps = np.diff(time_series.index.view('int64')).astype('float')
     t_steps = np.insert(t_steps, 0, np.nan)
     t_steps = pd.Series(index=time_series.index, data=t_steps)
     return t_steps
@@ -485,24 +495,24 @@ def energy_from_power(power, target_frequency=None, max_timedelta=None,
 
     Parameters
     ----------
-    power : pd.Series
+    power : pandas.Series
         Time series of power in Watts
-    target_frequency : DatetimeOffset or frequency string, default None
+    target_frequency : pandas.tseries.offsets.DateOffset or frequency string, default None
         The frequency of the energy time series to be returned.
         If omitted, use the median timestep of ``power``, or if ``power`` has
         fewer than two elements, use ``power.index.freq``.
-    max_timedelta : pd.Timedelta, default None
+    max_timedelta : pandas.Timedelta, default None
         The maximum allowed gap between power measurements. If the gap between
         consecutive power measurements exceeds ``max_timedelta``, NaN will be
         returned for that interval. If omitted, ``max_timedelta`` is set
         internally to the median time delta in ``power``. Ignored when ``power``
         has fewer than two elements.
-    power_type : {'right_labeled', 'instantaneous'}
+    power_type : str, {'right_labeled', 'instantaneous'}
         The labeling convention used in power. Default: 'right_labeled'
 
     Returns
     -------
-    pd.Series
+    pandas.Series
         right-labeled energy in Wh per interval
     '''
 
@@ -585,10 +595,10 @@ def _aggregate(time_series, target_frequency, max_timedelta, series_type):
 
     Parameters
     ----------
-    time_series : pd.Series
+    time_series : pandas.Series
     target_frequency : DatetimeOffset, or frequency string
         The frequency of the accumulated series to be returned.
-    max_timedelta : pd.Timedelta, default None
+    max_timedelta : pandas.Timedelta, default None
         The maximum allowed gap between power measurements. If the gap between
         consecutive power measurements exceeds ``max_timedelta``, no energy value
         will be returned for that interval.
@@ -598,7 +608,7 @@ def _aggregate(time_series, target_frequency, max_timedelta, series_type):
 
     Returns
     -------
-    pd.Series
+    pandas.Series
         right-labeled aggregated time_series in _*hours per interval
     '''
 
@@ -613,7 +623,7 @@ def _aggregate(time_series, target_frequency, max_timedelta, series_type):
     values = time_series.values
 
     # Identify gaps (including from nans) bigger than max_time_delta
-    timestamps = time_series.index.astype('int64').values
+    timestamps = time_series.index.view('int64')
     timestamps = pd.Series(timestamps, index=time_series.index)
     t_diffs = timestamps.diff()
     # Keep track of the gap size but with refilled NaNs and new
@@ -628,7 +638,7 @@ def _aggregate(time_series, target_frequency, max_timedelta, series_type):
         gap_mask[:time_series.index[0]] = True
 
     time_series = time_series.reindex(union_index)
-    t_diffs = np.diff(time_series.index.astype('int64').values)
+    t_diffs = np.diff(time_series.index.view('int64'))
     t_diffs_hours = t_diffs / 10**9 / 3600.0
     if series_type == 'instantaneous':
         # interpolate with trapz sum
@@ -663,11 +673,11 @@ def _interpolate_series(time_series, target_index, max_timedelta=None,
 
     Parameters
     ----------
-    time_series : pd.Series
+    time_series : pandas.Series
         Original values to be used in generating the interpolation
-    target_index : pd.DatetimeIndex
+    target_index : pandas.DatetimeIndex
         the index onto which the interpolation is to be made
-    max_timedelta : pd.Timedelta, default None
+    max_timedelta : pandas.Timedelta, default None
         The maximum allowed gap between values in time_series. Times associated
         with gaps longer than ``max_timedelta`` are excluded from the output. If
         omitted, ``max_timedelta`` is set internally to two times the median
@@ -680,7 +690,7 @@ def _interpolate_series(time_series, target_index, max_timedelta=None,
 
     Returns
     -------
-    pd.Series
+    pandas.Series
 
     Note
     ----
@@ -700,7 +710,7 @@ def _interpolate_series(time_series, target_index, max_timedelta=None,
     df = df.dropna()
 
     # convert to integer index and calculate the size of gaps in input
-    timestamps = df.index.astype('int64')
+    timestamps = df.index.view('int64')
     df['timestamp'] = timestamps
     df['gapsize_ns'] = df['timestamp'].diff()
     df.index = timestamps
@@ -720,7 +730,7 @@ def _interpolate_series(time_series, target_index, max_timedelta=None,
                       UserWarning)
 
     # put data on index that includes both original and target indicies
-    target_timestamps = target_index.astype('int64')
+    target_timestamps = pd.Index(target_index.view('int64'))
     union_index = df.index.append(target_timestamps)
     union_index = union_index.drop_duplicates(keep='first')
     df = df.reindex(union_index)
@@ -754,15 +764,15 @@ def interpolate(time_series, target, max_timedelta=None, warning_threshold=0.1):
 
     Parameters
     ----------
-    time_series : pd.Series, pd.DataFrame
+    time_series : pandas.Series, pandas.DataFrame
         Original values to be used in generating the interpolation
-    target : pd.DatetimeIndex, DatetimeOffset, or frequency string
+    target : pandas.DatetimeIndex, pandas.tseries.offsets.DateOffset, frequency string
 
         * If DatetimeIndex: the index onto which the interpolation is to be
           made
-        * If DatetimeOffset or frequency string: the frequency at which to
+        * If DateOffset or frequency string: the frequency at which to
           resample and interpolate
-    max_timedelta : pd.Timedelta, default None
+    max_timedelta : pandas.Timedelta, default None
         The maximum allowed gap between values in ``time_series``. Times
         associated with gaps longer than ``max_timedelta`` are excluded from the
         output. If omitted, ``max_timedelta`` is set internally to two times
@@ -775,7 +785,7 @@ def interpolate(time_series, target, max_timedelta=None, warning_threshold=0.1):
 
     Returns
     -------
-    pd.Series or pd.DataFrame (matching type of time_series) with DatetimeIndex
+    pandas.Series or pandas.DataFrame (matching type of time_series) with DatetimeIndex
 
     Note
     ----
